@@ -60,7 +60,7 @@ INTERNAL_VERSION = 0x0013
 __version__ = (2, 6, 1, INTERNAL_VERSION)
 
 # just a logger
-log = logging.getLogger(__name__)
+log = logging  # logging.getLogger(__name__)
 
 
 def version_info():
@@ -610,4 +610,4 @@ class CtrlPkg(object):
         """
         buff = select_recv(sock, cls.PACKAGE_SIZE, timeout)
         pkg, verify = CtrlPkg.decode_verify(buff, pkg_type=expect_ptype)  # type: CtrlPkg,bool
-        return pkg, verify
\ No newline at end of file
+        return pkg, verify
